@@ -96,12 +96,12 @@ class Join :
 
     @classmethod
     def getTable(cls, table) -> str :
-        valiTable = ''
+        validTable = ''
         if isinstance(table, str) :
-            valiTable += table
-        elif isinstance(table, bytes) or isinstance(table, bytearray) :
-            valiTable += str(table, 'utf-8')
-        return valiTable
+            validTable += table
+        elif isinstance(table, (bytes, bytearray)) :
+            validTable += str(table, 'utf-8')
+        return validTable
 
     def addColumn(self, baseColumn, joinColumn = None) :
         """Add columns object property to a join table object."""
