@@ -29,7 +29,7 @@ class Table :
         if isinstance(table, str) :
             name = table
             cls.table = table
-        elif isinstance(table, bytes) or isinstance(table, bytearray) :
+        elif isinstance(table, (bytes, bytearray)) :
             name = str(table, 'utf-8')
             cls.table = name
         elif isinstance(table, Mapping) and len(table) == 1 :
